@@ -1,5 +1,3 @@
-import asyncio
-import multiprocessing
 from multiprocessing import Queue, SimpleQueue, JoinableQueue
 
 from .executor import CoroBuilder
@@ -10,33 +8,32 @@ class AioBaseQueue(metaclass=CoroBuilder):
 
 
 class AioSimpleQueue(AioBaseQueue):
-    """ An asyncio-friendly version of mp.SimpleQueue. 
-    
+    """ An asyncio-friendly version of mp.SimpleQueue.
+
     Provides two asyncio.coroutines: coro_get and coro_put,
     which are asynchronous version of get and put, respectively.
-    
+
     """
     delegate = SimpleQueue
 
 
 class AioQueue(AioBaseQueue):
-    """ An asyncio-friendly version of mp.SimpleQueue. 
-    
+    """ An asyncio-friendly version of mp.SimpleQueue.
+
     Provides two asyncio.coroutines: coro_get and coro_put,
     which are asynchronous version of get and put, respectively.
-    
+
     """
     delegate = Queue
 
 
 class AioJoinableQueue(AioBaseQueue):
-    """ An asyncio-friendly version of mp.JoinableQueue. 
-    
+    """ An asyncio-friendly version of mp.JoinableQueue.
+
     Provides three asyncio.coroutines: coro_get, coro_put, and
     coro_join, which are asynchronous version of get put, and
     join, respectively.
-    
+
     """
     coroutines = ['join']
     delegate = JoinableQueue
-
